@@ -36,6 +36,7 @@ from braintree.masterpass_card import MasterpassCard
 from braintree.facilitated_details import FacilitatedDetails
 from braintree.facilitator_details import FacilitatorDetails
 from braintree.payment_instrument_type import PaymentInstrumentType
+from braintree.samsung_pay_card import SamsungPayCard
 
 class Transaction(Resource):
     """
@@ -98,6 +99,7 @@ class Transaction(Resource):
         "additional_processor_response",
         "amount",
         "authorization_adjustments",
+        "authorization_expires_at",
         "avs_error_response_code",
         "avs_postal_code_response_code",
         "avs_street_address_response_code",
@@ -113,6 +115,7 @@ class Transaction(Resource):
         "gateway_rejection_reason",
         "master_merchant_account_id",
         "merchant_account_id",
+        "network_transaction_id",
         "order_id",
         "payment_instrument_type",
         "payment_method_token",
@@ -245,6 +248,7 @@ class Transaction(Resource):
     class IndustryType(object):
         Lodging = "lodging"
         TravelAndCruise = "travel_cruise"
+        TravelAndFlight = "travel_flight"
 
     @staticmethod
     def clone_transaction(transaction_id, params):
@@ -553,12 +557,14 @@ class Transaction(Resource):
                     "store_shipping_address_in_vault",
                     "submit_for_settlement",
                     "venmo_sdk_session",
+                    "payee_id",
                     "payee_email",
                     "skip_advanced_fraud_checking",
                     "skip_avs",
                     "skip_cvv",
                     {
                         "paypal": [
+                            "payee_id",
                             "payee_email",
                             "custom_field",
                             "description",
@@ -592,18 +598,27 @@ class Transaction(Resource):
                 ]
             },
             {"custom_fields": ["__any_key__"]},
+            {"external_vault": ["status", "previous_network_transaction_id"]},
             {"descriptor": ["name", "phone", "url"]},
-            {"paypal_account": ["payee_email"]},
+            {"paypal_account": ["payee_id", "payee_email", "payer_id", "payment_id"]},
             {"industry":
                 [
                     "industry_type",
                     {
                         "data": [
-                            "folio_number", "check_in_date", "check_out_date", "departure_date", "lodging_check_in_date", "lodging_check_out_date", "travel_package", "lodging_name", "room_rate"
-                            ]
-                        }
-                    ]
-                },
+                            "folio_number", "check_in_date", "check_out_date", "departure_date", "lodging_check_in_date", "lodging_check_out_date", "travel_package", "lodging_name", "room_rate",
+                            "passenger_first_name", "passenger_last_name", "passenger_middle_initial", "passenger_title", "issued_date", "travel_agency_name", "travel_agency_code", "ticket_number",
+                            "issuing_carrier_code", "customer_code", "fare_amount", "fee_amount", "tax_amount", "restricted_ticket",
+                            {
+                                "legs": [
+                                    "conjunction_ticket", "exchange_ticket", "coupon_number", "service_class", "carrier_code", "fare_basis_code", "flight_number", "departure_date", "departure_airport_code", "departure_time",
+                                    "arrival_airport_code", "arrival_time", "stopover_permitted", "fare_amount", "fee_amount", "tax_amount", "endorsement_or_restrictions"
+                                ]
+                            }
+                        ]
+                    }
+                ]
+            },
             {"line_items":
                 [
                     "quantity", "name", "description", "kind", "unit_amount", "unit_tax_amount", "total_amount", "discount_amount", "tax_amount", "unit_of_measure", "product_code", "commodity_code", "url",
@@ -678,6 +693,8 @@ class Transaction(Resource):
             self.visa_checkout_card_details = VisaCheckoutCard(gateway, attributes.pop("visa_checkout_card"))
         if "masterpass_card" in attributes:
             self.masterpass_card_details = MasterpassCard(gateway, attributes.pop("masterpass_card"))
+        if "samsung_pay_card" in attributes:
+            self.samsung_pay_card_details = SamsungPayCard(gateway, attributes.pop("samsung_pay_card"))
         if "customer" in attributes:
             self.customer_details = Customer(gateway, attributes.pop("customer"))
         if "shipping" in attributes:
@@ -713,6 +730,8 @@ class Transaction(Resource):
             self.facilitated_details = FacilitatedDetails(attributes.pop("facilitated_details"))
         if "facilitator_details" in attributes:
             self.facilitator_details = FacilitatorDetails(attributes.pop("facilitator_details"))
+        if "network_transaction_id" in attributes:
+            self.network_transaction_id = attributes["network_transaction_id"]
 
     @property
     def refund_id(self):
